<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>FeatherNotes::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="171"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::ColorLabel</name>
    <message>
        <location filename="../../colorLabel.cpp" line="31"/>
        <source>Click to change color.</source>
        <translation>Нажмите чтобы изменить цвет.</translation>
    </message>
    <message>
        <location filename="../../colorLabel.cpp" line="53"/>
        <source>Select Color</source>
        <translation>Выберите цвет</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::FN</name>
    <message>
        <location filename="../../fn.ui" line="14"/>
        <source>FeatherNotes</source>
        <translation>FeatherNotes</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="65"/>
        <source>Next (F3)</source>
        <translation>Следующая (F3)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="68"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="81"/>
        <source>Previous (F4)</source>
        <translation>Предыдущая (F4)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="84"/>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="100"/>
        <source>Search...</source>
        <translation>Поиск...</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="115"/>
        <source>Search only in names (Ctrl+Shift+F7)</source>
        <translation>Искать только в именах (Ctrl+Shift+F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="118"/>
        <source>Ctrl+Shift+F7</source>
        <translation>Ctrl+Shift+F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="128"/>
        <source>Search only in tags (Shift+F7)</source>
        <translation>Искать только в тегах (Shift+F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="131"/>
        <source>Shift+F7</source>
        <translation>Shift+F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="144"/>
        <source>Search in all nodes (F7)</source>
        <translation>Искать во всех заметках (F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="147"/>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="186"/>
        <source>Whole Word (F6)</source>
        <translation>Слово целиком (F6)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="189"/>
        <source>Whole Word</source>
        <translation>Слово целиком</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="192"/>
        <source>F6</source>
        <translation>F6</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="167"/>
        <source>Match Case (F5)</source>
        <translation>С учётом регистра (F5)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="170"/>
        <source>Match Case</source>
        <translation>С учётом регистра</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="173"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="219"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="223"/>
        <source>Recenl&amp;y Opened</source>
        <translation>Недавние&amp;Открытые</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="245"/>
        <source>&amp;Edit</source>
        <translation>&amp;Правка</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="264"/>
        <source>For&amp;mat</source>
        <translation>Фор&amp;мат</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="296"/>
        <source>&amp;Tree</source>
        <translation>&amp;Дерево</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="320"/>
        <source>&amp;Options</source>
        <translation>Па&amp;раметры</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="334"/>
        <source>&amp;Search</source>
        <translation>&amp;Поиск</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="341"/>
        <location filename="../../fn.ui" line="987"/>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="436"/>
        <source>Find:</source>
        <translation>Найти:</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="443"/>
        <source>Replace with:</source>
        <translation>Заменить на:</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="456"/>
        <source>To be replaced</source>
        <translation>Подлежит замене</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="469"/>
        <source>Replacing text</source>
        <translation>Заменяющий текст</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="479"/>
        <source>Previous (F9)</source>
        <translation>Предыдущий (F9)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="482"/>
        <source>F9</source>
        <translation>F9</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="495"/>
        <source>Next (F8)</source>
        <translation>Далее (F8)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="498"/>
        <source>F8</source>
        <translation>F8</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="511"/>
        <source>Replace all (F10)</source>
        <translation>Заменить всё (F10)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="514"/>
        <source>F10</source>
        <translation>F10</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="531"/>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="534"/>
        <location filename="../../fn.cpp" line="1018"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="537"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="542"/>
        <location filename="../../fn.cpp" line="678"/>
        <source>&amp;Open</source>
        <translation>&amp;Открыть</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="545"/>
        <source>Open a file</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="548"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="556"/>
        <source>&amp;Undo</source>
        <translation>&amp;Отменить</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="559"/>
        <source>Undo</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="562"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="570"/>
        <source>&amp;Redo</source>
        <translation>&amp;Повторить</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="573"/>
        <source>Redo</source>
        <translation>Повторить</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="576"/>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="584"/>
        <source>&amp;Find</source>
        <translation>&amp;Найти</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="587"/>
        <source>Show/hide searchbar</source>
        <translation>Показать/скрыть строку поиска</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="590"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="598"/>
        <source>&amp;Clear All Formats</source>
        <translation>&amp;Очистить форматирование</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="601"/>
        <source>Clear all formats</source>
        <translation>Очистить форматирование</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="604"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="615"/>
        <source>&amp;Bold</source>
        <translation>Полу&amp;жирный</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="618"/>
        <source>Bold</source>
        <translation>Полужирный</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="621"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="632"/>
        <source>&amp;Italic</source>
        <translation>К&amp;урсив</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="635"/>
        <source>Italic</source>
        <translation>Курсив</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="638"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="649"/>
        <source>&amp;Underline</source>
        <translation>По&amp;дчёркнутый</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="652"/>
        <source>Underline</source>
        <translation>Подчёркнутый</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="655"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="666"/>
        <source>&amp;Strike Through</source>
        <translation>&amp;Зачёркнутый</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="669"/>
        <source>Strike through</source>
        <translation>Зачёркнутый</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="672"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="680"/>
        <source>Te&amp;xt Color</source>
        <translation>Цвет текс&amp;та</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="683"/>
        <source>Text color</source>
        <translation>Цвет текста</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="686"/>
        <source>Alt+Shift+T</source>
        <translation>Alt+Shift+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="694"/>
        <source>Back&amp;ground Color</source>
        <translation>Цвет фо&amp;на</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="697"/>
        <source>Background color</source>
        <translation>Цвет фона</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="700"/>
        <source>Alt+Shift+B</source>
        <translation>Alt+Shift+B</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="705"/>
        <source>Options</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="710"/>
        <location filename="../../fn.cpp" line="677"/>
        <source>&amp;New Note</source>
        <translation>&amp;Новая заметка</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="713"/>
        <source>Ctrl+Alt+Shift+N</source>
        <translation>Ctrl+Alt+Shift+N</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="721"/>
        <source>Save &amp;As</source>
        <translation>Сохранить &amp;как</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="724"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="732"/>
        <source>&amp;Print</source>
        <translation>&amp;Печать</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="735"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="743"/>
        <source>P&amp;rint with Sub-Nodes</source>
        <translation>Пе&amp;чать со вложенными заметками</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="751"/>
        <source>Set Pass&amp;word</source>
        <translation>Установить па&amp;роль</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="756"/>
        <location filename="../../fn.cpp" line="680"/>
        <source>&amp;Quit</source>
        <translation>&amp;Выйти</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="759"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="767"/>
        <source>&amp;Cut</source>
        <translation>&amp;Вырезать</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="770"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="778"/>
        <source>C&amp;opy</source>
        <translation>&amp;Копировать</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="781"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="789"/>
        <source>&amp;Paste</source>
        <translation>&amp;Вставить</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="792"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="800"/>
        <source>&amp;Delete</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="808"/>
        <source>&amp;Select All</source>
        <translation>&amp;Выделить всё</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="811"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="819"/>
        <source>E&amp;mbed Image</source>
        <translation>В&amp;ставить изображение</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="822"/>
        <location filename="../../fn.cpp" line="4414"/>
        <source>Embed Image</source>
        <translation>Вставить изображение</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="825"/>
        <source>Ctrl+Alt+Shift+I</source>
        <translation>Ctrl+Alt+Shift+I</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="833"/>
        <source>E&amp;xpand All</source>
        <translation>&amp;Развернуть всё</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="836"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="844"/>
        <source>Collap&amp;se All</source>
        <translation>Сверну&amp;ть всё</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="847"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="855"/>
        <source>&amp;Append Sibling</source>
        <translation>&amp;Добавить заметку снизу</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="858"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="866"/>
        <source>Append &amp;Child</source>
        <translation>Вложить &amp;заметку</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="869"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="877"/>
        <source>&amp;Delete Node</source>
        <translation>&amp;Удалить заметку</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="880"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="888"/>
        <source>Move &amp;Up</source>
        <translation>Переместить вв&amp;ерх</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="891"/>
        <source>Alt+Up</source>
        <translation>Alt+Up</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="899"/>
        <source>Move Do&amp;wn</source>
        <translation>Переместить вни&amp;з</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="902"/>
        <source>Alt+Down</source>
        <translation>Alt+Down</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="910"/>
        <source>Re&amp;name Node</source>
        <translation>Пере&amp;именовать заметку</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="913"/>
        <source>Ctrl+Shift+R</source>
        <translation>Ctrl+Shift+R</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="918"/>
        <source>Tree Pr&amp;operties</source>
        <translation>&amp;Свойства дерева</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="921"/>
        <source>Ctrl+Shift+D</source>
        <translation>Ctrl+Shift+D</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="929"/>
        <source>Document &amp;Font</source>
        <translation>&amp;Шрифт документа</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="943"/>
        <source>&amp;Wrap Lines</source>
        <translation>&amp;Переносить строки</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="946"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="960"/>
        <source>&amp;Auto-Indentation</source>
        <translation>&amp;Автоматический отступ</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="963"/>
        <source>Ctrl+Shift+I</source>
        <translation>Ctrl+Shift+I</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="968"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="971"/>
        <source>Ctrl+Shift+P</source>
        <translation>Ctrl+Shift+P</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="979"/>
        <source>Find and &amp;Replace</source>
        <translation>Н&amp;айти и заменить</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="982"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="990"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="995"/>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1003"/>
        <source>Pr&amp;int All Nodes</source>
        <translation>Пе&amp;чать всех заметок</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1014"/>
        <source>Superscrip&amp;t</source>
        <translation>Верхний &amp;индекс</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1017"/>
        <source>Superscript</source>
        <translation>Верхний индекс</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1020"/>
        <source>Alt+Shift+U</source>
        <translation>Alt+Shift+U</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1031"/>
        <source>Subscri&amp;pt</source>
        <translation>Нижний &amp;индекс</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1034"/>
        <source>Subscript</source>
        <translation>Нижний индекс</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1037"/>
        <source>Alt+Shift+S</source>
        <translation>Alt+Shift+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1048"/>
        <source>C&amp;enter</source>
        <translation>По &amp;центру</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1051"/>
        <source>Align center</source>
        <translation>По центру</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1054"/>
        <source>Alt+Shift+Down</source>
        <translation>Alt+Shift+Down</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1065"/>
        <location filename="../../fn.cpp" line="2217"/>
        <source>&amp;Right</source>
        <translation>&amp;По правому краю</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1068"/>
        <source>Align right</source>
        <translation>По правому краю</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1071"/>
        <source>Alt+Shift+Right</source>
        <translation>Alt+Shift+Right</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1082"/>
        <location filename="../../fn.cpp" line="2211"/>
        <source>&amp;Left</source>
        <translation>&amp;По левому краю</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1085"/>
        <source>Align left</source>
        <translation>По левому краю</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1088"/>
        <source>Alt+Shift+Left</source>
        <translation>Alt+Shift+Left</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1099"/>
        <source>&amp;Justify</source>
        <translation>По &amp;ширине</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1102"/>
        <source>Justify</source>
        <translation>По ширине</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1105"/>
        <source>Alt+Shift+Up</source>
        <translation>Alt+Shift+Up</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1113"/>
        <source>&amp;Prepend Sibling</source>
        <translation>&amp;Добавить заметку сверху</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1116"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1124"/>
        <source>Move &amp;Left</source>
        <translation>Переместить &amp;влево</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1127"/>
        <source>Alt+Left</source>
        <translation>Alt+Влево</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1135"/>
        <source>Move &amp;Right</source>
        <translation>Переместить &amp;вправо</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1138"/>
        <source>Alt+Right</source>
        <translation>Alt+Вправо</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1146"/>
        <source>h&amp;2</source>
        <translation>Заголовок &amp;2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1149"/>
        <source>Header 2</source>
        <translation>Заголовок 2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1152"/>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1160"/>
        <source>h&amp;1</source>
        <translation>Заголовок &amp;1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1163"/>
        <source>Header 1</source>
        <translation>Заголовок 1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1166"/>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1174"/>
        <source>h&amp;3</source>
        <translation>Заголовок &amp;3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1177"/>
        <source>Header 3</source>
        <translation>Заголовок 3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1180"/>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1188"/>
        <source>&amp;Node Font</source>
        <translation>&amp;Шрифт заметки</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1191"/>
        <source>Node Font</source>
        <translation>Шрифт заметки</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1196"/>
        <source>Scale I&amp;mage(s)</source>
        <translation>Масштаб изобра&amp;жения(-й)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1204"/>
        <source>Paste &amp;HTML</source>
        <translation>Вставить &amp;HTML</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1207"/>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1215"/>
        <source>&amp;Tags</source>
        <translation>&amp;Теги</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1218"/>
        <source>Ctrl+Shift+T</source>
        <translation>Ctrl+Shift+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1226"/>
        <source>Insert Lin&amp;k</source>
        <translation>Вставить ссыл&amp;ку</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1229"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1234"/>
        <source>C&amp;opy Link</source>
        <translation>К&amp;опировать ссылку</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1242"/>
        <source>I&amp;nsert Table</source>
        <translation>В&amp;ставить таблицу</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1245"/>
        <source>Ctrl+Alt+Shift+T</source>
        <translation>Ctrl+Alt+Shift+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1250"/>
        <source>Append Row</source>
        <translation>Добавить строку снизу</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1255"/>
        <source>Delete Row</source>
        <translation>Удалить строку</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1260"/>
        <source>Append Column</source>
        <translation>Добавить столбец справа</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1265"/>
        <source>Delete Column</source>
        <translation>Удалить столбец</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1270"/>
        <source>Merge Cells</source>
        <translation>Объединить ячейки</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1275"/>
        <source>Prepend Row</source>
        <translation>Добавить строку сверху</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1280"/>
        <source>Prepend Column</source>
        <translation>Добавить столбец слева</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1288"/>
        <source>Export &amp;HTML</source>
        <translation>Экспорт &amp;HTML</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1293"/>
        <source>Save Ima&amp;ge(s)</source>
        <translation>Сохранить изобра&amp;жение(-я)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1304"/>
        <source>RTL</source>
        <translation>Письмо справа налево</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1307"/>
        <source>Ctrl+Alt+Shift+Left</source>
        <translation>Ctrl+Alt+Shift+Left</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1318"/>
        <source>LTR</source>
        <translation>Письмо слева направо</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1321"/>
        <source>Ctrl+Alt+Shift+Right</source>
        <translation>Ctrl+Alt+Shift+Right</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1326"/>
        <location filename="../../fn.ui" line="1329"/>
        <source>Menu</source>
        <translation>Меню</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1337"/>
        <source>Node &amp;Icon</source>
        <translation>&amp;Значок заметки</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1340"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Shift+C</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1345"/>
        <location filename="../../fn.ui" line="1348"/>
        <source>Check Spelling</source>
        <translation>Проверить орфографию</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1351"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1356"/>
        <source>Document &amp;Colors</source>
        <translation>Документы &amp;Цвета</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1364"/>
        <location filename="../../fn.ui" line="1367"/>
        <source>Paste Date and Time</source>
        <translation>Вставить дату и время</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1372"/>
        <source>&amp;Clear</source>
        <translation>&amp;Очистить</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3001"/>
        <source>Node Icon</source>
        <translation>Значок заметки</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="674"/>
        <source>&amp;Raise/Hide</source>
        <translation>&amp;Раскрыть/Свернуть</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="914"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;New note?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Новая заметка?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="915"/>
        <source>&lt;center&gt;&lt;i&gt;Do you really want to leave this document&lt;/i&gt;&lt;/center&gt;
&lt;center&gt;&lt;i&gt;and create an empty one?&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Вы действительно хотите оставить этот документ&lt;/i&gt;&lt;/center&gt;
&lt;center&gt;&lt;i&gt;и создать пустой?&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="918"/>
        <location filename="../../fn.cpp" line="2832"/>
        <location filename="../../fn.cpp" line="4777"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="919"/>
        <location filename="../../fn.cpp" line="2833"/>
        <location filename="../../fn.cpp" line="4778"/>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1010"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Save changes?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Сохранить изменения?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1012"/>
        <source>&lt;center&gt;&lt;i&gt;The document has been modified.&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Документ был изменён.&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1014"/>
        <source>&lt;center&gt;&lt;i&gt;The document has been removed.&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Документ был удалён.&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1019"/>
        <source>Discard changes</source>
        <translation>Забыть изменения</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1020"/>
        <location filename="../../fn.cpp" line="2950"/>
        <location filename="../../fn.cpp" line="3044"/>
        <location filename="../../fn.cpp" line="3317"/>
        <location filename="../../fn.cpp" line="4353"/>
        <location filename="../../fn.cpp" line="4438"/>
        <location filename="../../fn.cpp" line="4616"/>
        <location filename="../../fn.cpp" line="4879"/>
        <location filename="../../fn.cpp" line="5827"/>
        <location filename="../../fn.cpp" line="6106"/>
        <location filename="../../fn.cpp" line="6204"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1484"/>
        <source>Open file...</source>
        <translation>Открыть файл...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1661"/>
        <location filename="../../fn.cpp" line="5953"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be saved!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Сохранение невозможно!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3613"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1761"/>
        <location filename="../../fn.cpp" line="1784"/>
        <source>Save As...</source>
        <translation>Сохранить как...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1486"/>
        <location filename="../../fn.cpp" line="1763"/>
        <location filename="../../fn.cpp" line="1786"/>
        <source>FeatherNotes documents</source>
        <translation>Документы FeatherNotes</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1486"/>
        <location filename="../../fn.cpp" line="1763"/>
        <location filename="../../fn.cpp" line="1786"/>
        <location filename="../../fn.cpp" line="3033"/>
        <location filename="../../fn.cpp" line="4537"/>
        <location filename="../../fn.cpp" line="4808"/>
        <source>All Files</source>
        <translation>Все файлы</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2829"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Delete this node?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Удалить эту заметку?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2830"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;i&gt;Warning!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
&lt;center&gt;This action cannot be undone.&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;i&gt;Внимание!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
&lt;center&gt;Это действие нельзя отменить.&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2936"/>
        <source>Tags</source>
        <translation>Теги</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2951"/>
        <location filename="../../fn.cpp" line="3045"/>
        <location filename="../../fn.cpp" line="3318"/>
        <location filename="../../fn.cpp" line="4355"/>
        <location filename="../../fn.cpp" line="4439"/>
        <location filename="../../fn.cpp" line="4617"/>
        <location filename="../../fn.cpp" line="4880"/>
        <location filename="../../fn.cpp" line="5829"/>
        <location filename="../../fn.cpp" line="6107"/>
        <location filename="../../fn.cpp" line="6205"/>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3033"/>
        <location filename="../../fn.cpp" line="4537"/>
        <location filename="../../fn.cpp" line="4808"/>
        <source>Image Files</source>
        <translation>Файлы изображений</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3125"/>
        <location filename="../../fn.cpp" line="3158"/>
        <source>&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</source>
        <translation>&lt;b&gt;Основных заметок:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;Всего заметок:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3131"/>
        <location filename="../../fn.cpp" line="3164"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</source>
        <translation>&lt;b&gt;Информация:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;Основных заметок:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;Всего заметок:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3600"/>
        <source>%1 Matches</source>
        <translation>%1 совпадений</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3602"/>
        <source>One Match</source>
        <translation>Одно совпадение</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3604"/>
        <location filename="../../fn.cpp" line="3971"/>
        <source>No Match</source>
        <translation>Нет совпадений</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3770"/>
        <location filename="../../fn.cpp" line="3823"/>
        <source>Replacement</source>
        <translation>Замена</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4078"/>
        <source>No Replacement</source>
        <translation>Без замены</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4080"/>
        <source>One Replacement</source>
        <translation>Одна замена</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4083"/>
        <source>%1 Replacements</source>
        <translation>%1 замены</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4341"/>
        <source>Insert Link</source>
        <translation>Вставить ссылку</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6050"/>
        <source>HTML Files</source>
        <translation>Файлы HTML</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3009"/>
        <location filename="../../fn.cpp" line="4423"/>
        <source>Image path</source>
        <translation>Путь к изображению</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3013"/>
        <location filename="../../fn.cpp" line="4427"/>
        <source>Open image</source>
        <translation>Открыть изображение</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4435"/>
        <location filename="../../fn.cpp" line="4613"/>
        <source>Scaling percentage</source>
        <translation>Процент масштабирования</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3031"/>
        <location filename="../../fn.cpp" line="4535"/>
        <source>Open Image...</source>
        <translation>Открыть изображение...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="649"/>
        <source>System tray is not available.
Please disable tray in Preferences.</source>
        <translation>Системный трей недоступен.
Пожалуйста, отключите трей в параметрах.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="965"/>
        <source>New Node</source>
        <translation>Новая заметка</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1662"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be opened!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Не может быть открыто!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1743"/>
        <location filename="../../fn.cpp" line="5668"/>
        <location filename="../../fn.cpp" line="5677"/>
        <location filename="../../fn.cpp" line="5816"/>
        <location filename="../../fn.cpp" line="6007"/>
        <location filename="../../fn.cpp" line="6016"/>
        <location filename="../../fn.cpp" line="6043"/>
        <source>Untitled</source>
        <translation>Безымянный</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2210"/>
        <source>Align Table</source>
        <translation>Выровнять таблицу</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2223"/>
        <source>&amp;Center</source>
        <translation>Центрировать</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2662"/>
        <source>Select Text Color</source>
        <translation>Выбор цвета текста</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2694"/>
        <source>Select Background Color</source>
        <translation>Выбор цвета фона</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2828"/>
        <source>Deletion</source>
        <translation>Удаление</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2946"/>
        <source>Tag(s) for this node</source>
        <translation>Тег(и) этой заметки</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3202"/>
        <source>Select Document Font</source>
        <translation>Выбор шрифта документа</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3264"/>
        <source>Select Node Font</source>
        <translation>Выбор шрифта заметки</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3289"/>
        <source>Set Document Colors</source>
        <translation>Установить цвета документа</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3299"/>
        <source>These colors will be applied to new nodes.&lt;br&gt;They may or may not affect existing nodes&lt;br&gt;but document reopening is recommended.</source>
        <translation>Эти цвета будут применены к новым записям. &lt;br&gt; Они могут повлиять или не повлиять на существующие записи, &lt;br&gt; но рекомендуется повторно открыть эту запись.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3302"/>
        <source>Background color:</source>
        <translation>Задний цвет:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3308"/>
        <source>Text color:</source>
        <translation>Цвет текста:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4088"/>
        <source>The first 1000 replacements are highlighted.</source>
        <translation>Выделены первые 1000 замен.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4430"/>
        <location filename="../../fn.cpp" line="4609"/>
        <source>Scale to</source>
        <translation>Масштабировать до</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4434"/>
        <location filename="../../fn.cpp" line="4612"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4603"/>
        <source>Scale Image(s)</source>
        <translation>Масштаб изображения(-ий)</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4740"/>
        <source>untitled</source>
        <translation>безымянный</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4772"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4773"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Image cannot be saved! Retry?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Не удалось сохранить изображение! Повторить попытку?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4774"/>
        <source>&lt;center&gt;Maybe you did not choose a proper extension&lt;/center&gt;
&lt;center&gt;or do not have write permission.&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</source>
        <translation>&lt;center&gt;Возможно, вы выбрали неправильное расширение&lt;/center&gt;
&lt;center&gt;или у вас недостаточно прав на запись.&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4806"/>
        <source>Save Image As...</source>
        <translation>Сохранить изображение как...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4861"/>
        <source>Insert Table</source>
        <translation>Вставить таблицу</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4867"/>
        <source>Rows:</source>
        <translation>Строк:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4873"/>
        <source>Columns:</source>
        <translation>Столбцов:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5757"/>
        <source>Print Document</source>
        <translation>Печать документа</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5763"/>
        <source>Printing completed.</source>
        <translation>Печать завершена.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5765"/>
        <source>Printing in progress...</source>
        <translation>Идет печать ...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5784"/>
        <source>Export HTML</source>
        <translation>Экспорт HTML</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5789"/>
        <source>Export:</source>
        <translation>Экспорт:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5790"/>
        <source>&amp;Current node</source>
        <translation>&amp;Текущая заметка</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5792"/>
        <source>With all &amp;sub-nodes</source>
        <translation>Со всеми &amp;вложенными заметками</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5793"/>
        <source>&amp;All nodes</source>
        <translation>&amp;Все заметки</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5805"/>
        <source>Output file:</source>
        <translation>Выходной файл:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5824"/>
        <source>Select path</source>
        <translation>Выберите путь</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5865"/>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5866"/>
        <source>The file already exists.
Do you want to replace it?
</source>
        <translation>Файл уже существует.
Вы хотите заменить его?
</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6048"/>
        <source>Save HTML As...</source>
        <translation>Сохранить HTML как...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6074"/>
        <source>Set Password</source>
        <translation>Задать пароль</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6083"/>
        <source>Type password</source>
        <translation>Введите пароль</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6095"/>
        <source>Retype password</source>
        <translation>Повторите ввод пароля</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6167"/>
        <source>&lt;center&gt;Passwords were different. Retry!&lt;/center&gt;</source>
        <translation>&lt;center&gt;Пароли не совпадают. Повторите попытку!&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6187"/>
        <location filename="../../fn.cpp" line="6195"/>
        <source>Enter Password</source>
        <translation>Введите пароль</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6267"/>
        <source>&lt;center&gt;Wrong password. Retry!&lt;/center&gt;</source>
        <translation>&lt;center&gt;Неверный пароль. Повторите попытку!&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6309"/>
        <source>A lightweight notes manager</source>
        <translation>Легковесный менеджер заметок</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6310"/>
        <source>based on Qt</source>
        <translation>основан на Qt</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6311"/>
        <source>Author</source>
        <translation>Автор</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6313"/>
        <location filename="../../fn.cpp" line="6314"/>
        <source>About FeatherNotes</source>
        <translation>О FeatherNotes</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6313"/>
        <source>Translators</source>
        <translation>Переводчики</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6497"/>
        <source>See Preferences → Text → Spell Checking!</source>
        <translation>См. Настройки → Текст → Проверка орфографии!</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6513"/>
        <source>You need to add a Hunspell dictionary.</source>
        <translation>Вам нужно добавить словарь Hunspell.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6518"/>
        <source>The Hunspell dictionary does not exist.</source>
        <translation>Словарь Hunspell не найден.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6526"/>
        <source>The Hunspell dictionary is not accompanied by an affix file.</source>
        <translation>Словарь Hunspell не сопровождается файлом аффикса.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6544"/>
        <location filename="../../fn.cpp" line="6559"/>
        <location filename="../../fn.cpp" line="6571"/>
        <source>No misspelling from text cursor.</source>
        <translation>Нет текста для поверки орфографии от курсора.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6583"/>
        <source>Spell Checking</source>
        <translation>Проверка орфографии</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6312"/>
        <source>aka.</source>
        <translation>альтернативное имя.</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::LineEdit</name>
    <message>
        <location filename="../../lineedit.cpp" line="35"/>
        <source>Clear text (Ctrl+K)</source>
        <translation>Удалить текст (Ctrl+K)</translation>
    </message>
    <message>
        <location filename="../../lineedit.cpp" line="81"/>
        <source>Ctrl+K</source>
        <comment>Clear text</comment>
        <translation>Ctrl+K</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::PrefDialog</name>
    <message>
        <location filename="../../prefDialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="27"/>
        <source>Window</source>
        <translation>Окно</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="36"/>
        <source>Saves window size after closing
this dialog and also on exit.

Uncheck to set a fixed size!</source>
        <translation>Сохраняет размер окна после закрытия
этого диалога, а также после выхода.

Снимите флажок, чтобы зафиксировать размер!</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="42"/>
        <source>Remember window &amp;size</source>
        <translation>Запомнить размер &amp;окна</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="51"/>
        <source>Start with this size: </source>
        <translation>Начать с данного размера: </translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="58"/>
        <location filename="../../prefDialog.ui" line="72"/>
        <source> px</source>
        <translation> пикс</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="97"/>
        <source>Saves tree width after closing
this dialog and also on exit.

Uncheck for a width ratio of 170/530.</source>
        <translation>Сохраняет ширину дерева после закрытия
этого диалога, а также после выхода.

Снимите флажок для ширины 170/530.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="103"/>
        <source>Remember &amp;tree width</source>
        <translation>Запомнить ширину &amp;дерева</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="110"/>
        <source>Saves position after closing
this dialog and also on exit.

This may not work correctly
with some window managers.</source>
        <translation>Сохраняет позицию после закрытия
этого диалога и на выходе.

Может работать некорректно с
некоторыми оконными менеджерами.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="117"/>
        <source>Save &amp;position</source>
        <translation>Сохранить &amp;расположение</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="124"/>
        <source>Decides whether a systray icon should be used.
If checked, the titlebar close button iconifies
the window to the systray instead of quitting.

Needs restarting of FeatherNotes to take effect.</source>
        <translation>Если флажок установлен, нажатие на кнопку
закрытия, вместо выхода, свернёт окно в системный лоток.

Для вступления в силу потребуется перезапуск FeatherNotes.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="131"/>
        <source>Add to s&amp;ystray</source>
        <translation>Добавить в системный &amp;лоток</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="156"/>
        <source>The command line option --tray
can be used instead of this.</source>
        <translation>Вместо этого можно использовать
опцию командной строки --tray.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="160"/>
        <source>Start i&amp;conified to tray</source>
        <translation>Запускать с&amp;вёрнутым в лоток</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="169"/>
        <source>Merge the tree view with its surroundings?</source>
        <translation>Объединить вид дерева с текущим окружением?</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="172"/>
        <source>Transparent t&amp;ree view</source>
        <translation>Прозрачный вид &amp;дерева</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="179"/>
        <source>By default, the active widget style determines
the size of toolbar icons.</source>
        <translation>По умолчанию, активный стиль виджетов
определяет размер значков панели инструментов.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="183"/>
        <source>Small toolbar icons</source>
        <translation>Маленькие значки панели инструментов</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="190"/>
        <source>Do not show t&amp;oolbar</source>
        <translation>Скрыть панель &amp;инструментов</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="197"/>
        <source>If the menubar is hidden,
a menu button appears on the toolbar.</source>
        <translation>При скрытии панели меню, кнопка меню
расположится на панели инструментов.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="201"/>
        <source>Do not show &amp;menubar</source>
        <translation>Скрыть &amp;панель меню</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="228"/>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="237"/>
        <source>&amp;Wrap lines by default</source>
        <translation>&amp;Выделять линии по умолчанию</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="244"/>
        <source>Auto-&amp;indent by default</source>
        <translation>&amp;Автоматический отступ по умолчанию</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="251"/>
        <source>This covers parentheses, braces, brackets and quotes.

Needs restarting of FeatherNotes to take effect.</source>
        <translation>Это касается круглых, фигурных, квадратных скобок и кавычек.

Для вступления в силу потребуется перезапуск FeatherNotes.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="256"/>
        <source>Auto-&amp;bracket</source>
        <translation>&amp;Автоматическое закрытие скобок</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="263"/>
        <source>A triple period is replaced with an ellipsis,
a double hyphen with a long dash, etc. while
the user is typing and under proper circumstances.</source>
        <translation>Три точки заменяются многоточием,
двойной дефис — длинным тире и т.д.
во время ввода текста и при определённых условиях.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="268"/>
        <source>&amp;Replace some characters while typing</source>
        <translation>&amp;Заменять некоторые символы при вводе</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="277"/>
        <location filename="../../prefDialog.ui" line="290"/>
        <source>Used for pasting the date and time.
Leave empty for the system default.

Takes effect after closing this dialog.</source>
        <translation>Используется для вставки даты и времени.
Оставьте пустым для системного значения по умолчанию.

Вступает в силу после закрытия этого диалога.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="283"/>
        <source>Date and time format:</source>
        <translation>Формат даты и времени:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="307"/>
        <source>&amp;Auto-save every</source>
        <translation>&amp;Сохранять каждые</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="314"/>
        <source> minute(s)</source>
        <translation> минут(-ы)</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="348"/>
        <source>If this option is checked, the opened document will
be saved on exiting without prompt and without
showing a warning if saving is not possible.</source>
        <translation>Если эта опция выбрана, документ будет сохранён
при закрытии без предупреждения и без
отображения ошибки если сохранение невозможно.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="353"/>
        <source>Save opened document on exiting</source>
        <translation>Сохранять открытый документ при выходе</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="376"/>
        <source>Spell Checking</source>
        <translation>Проверка орфографии</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="384"/>
        <location filename="../../prefDialog.ui" line="396"/>
        <source>A Hunspell dictionary has a name that ends with &quot;.dic&quot;
and should be alongside an affix file with the same
name but ending with &quot;.aff&quot;.</source>
        <translation>Словарь Hunspell имеет имя, которое оканчивается на «.dic»,
он должен находиться рядом с аффиксным файлом с тем же
именем, но оканчивающимся на «.aff».</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="389"/>
        <source>Hunspell dictionary path:</source>
        <translation>Путь к словарю Hunspell:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="408"/>
        <location filename="../../pref.cpp" line="647"/>
        <source>Add dictionary...</source>
        <translation>Добавьте словарь...</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="443"/>
        <source>Files</source>
        <translation>Файлы</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="452"/>
        <source>Start with the last opened file</source>
        <translation>Начать с последнего открытого файла</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="464"/>
        <source>Number of recent files:</source>
        <translation>Количество последних файлов:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="496"/>
        <source>Open recent files separately</source>
        <translation>Открывать последние файлы отдельно</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="503"/>
        <source>By default, all nodes are expanded on opening a document.</source>
        <translation>Все элементы отображаются по умолчанию при открытии документа.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="506"/>
        <source>Remember expanded states of nodes</source>
        <translation>Сохранить состояния отображаемых элементов</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="530"/>
        <source>Shortcuts</source>
        <translation>Комбинации клавиш</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="549"/>
        <source>Action</source>
        <translation>Действие</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="554"/>
        <source>Shortcut</source>
        <translation>Комбинация клавиш</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="562"/>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="340"/>
        <location filename="../../pref.cpp" line="520"/>
        <source>Warning: Ambiguous shortcut detected!</source>
        <translation>Внимание: обнаружена неоднозначная комбинация!</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="503"/>
        <source>The typed shortcut was reserved.</source>
        <translation>Введённая комбинация клавиш уже используется.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="618"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>Для вступления изменений в силу перезапустите приложение.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="649"/>
        <source>Hunspell Dictionary Files</source>
        <translation>Файлы словаря Hunspell</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::SpellDialog</name>
    <message>
        <location filename="../../spellDialog.ui" line="25"/>
        <source>Unknown word:</source>
        <translation>Неизвестное слово:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="51"/>
        <source>Add To Dictionary</source>
        <translation>Добавить в словарь</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="62"/>
        <source>Replace with:</source>
        <translation>Заменить на:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="87"/>
        <source>Ignore Once</source>
        <translation>Игнорировать один раз</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="100"/>
        <source>Ignore All</source>
        <translation>Игнорировать</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="129"/>
        <source>Correct Once</source>
        <translation>Исправить</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="142"/>
        <source>Correct All</source>
        <translation>Исправить всё</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::helpDialog</name>
    <message>
        <location filename="../../helpDialog.ui" line="14"/>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../domitem.cpp" line="100"/>
        <location filename="../../domitem.cpp" line="137"/>
        <source>New Node</source>
        <translation>Новая заметка</translation>
    </message>
</context>
</TS>
